# %rel, %ver, %LSBRelease are defined in the Makefile

Summary: LSB X Window System Test Suite (XTS5)
Name: lsb-test-xts5
Version: %{ver}
Release: %{rel}.lsb%{LSBRelease}
License: MIT
Group: Development/Tools
Source0: xts5-5.1.5.tar.gz
Source1: %{name}-%{version}.tar.gz
Patch0: xts5-5.1.5-lsb-generic.patch
Patch1: xts5-5.1.5-lsb-Xt.patch
Patch2: xts5-5.1.5-lsb-Xlib.patch
Patch3: xts5-5.1.5-lsb-XI.patch
Patch4: xts5-5.1.5-bug-1589.patch
Patch5: xts5-5.1.5-drop-Xt-tests.patch
Patch6: xts5-5.1.5-lsbcc.patch
Patch7: lsb-test-xts5-handle-xcb.patch
Patch8: xts5-5.1.5-bug-1906.patch
Patch9: xts5-5.1.5-bug-1937.patch

URL: http://www.linuxbase.org/test
#Prefix: %{_prefix}
BuildRoot: %{_tmppath}/%{name}-root
AutoReqProv: no
Requires: lsb-tet3-lite
Requires: lsb-xvfb
BuildRequires: lsb-tet3-lite-devel
%define	tet_root	%{_libdir}/tet

%description
This is the official package version of LSB X Window System test suite.
These tests are derived from the XTS5 test suites.

#==================================================
%prep
%setup -c -q -n %{name}-%{version}
tar xzf %{SOURCE1} -C ../
%patch -p0 -b .lsb-xts5-generic
%patch1 -p0 -b .lsb-xts5-Xt
%patch2 -p0 -b .lsb-xts5-Xlib
%patch3 -p0 -b .lsb-xts5-XI
%patch4 -p0 -b .lsb-1589
%patch6 -p0 -b .lsbcc
%patch7 -p0 -b .xcb
%patch8 -p0 -b .bug-1906
%patch9 -p0 -b .bug-1937
#something weird with empty files on SLES10, mode 0000
chmod 0660 xts5/src/lib/*.lsbcc

# Modify kycdtkysym, lkpkysym tests to not use 'index', 
# which is called out in updated LSB strings.h
# turns out these test were silently not building
# fixed the same issue in vsw4 back in July '07
sed -i 's|index|xindex|g' xts5/tset/Xlib17/kycdtkysym/kycdtkysym.m
sed -i 's|index|xindex|g' xts5/tset/Xlib17/lkpkysym/lkpkysym.m

#==================================================
%build
# We want to build with lsbcc. Until that's possible,
# force the LSB dynamic linker so the system under test
# will use the libraries normally used for LSB conformance
LDSO_VERSION=3
%ifarch %{ix86}
LDSO=/lib/ld-lsb.so.$LDSO_VERSION
%endif
%ifarch ppc
LDSO=/lib/ld-lsb-ppc32.so.$LDSO_VERSION
%endif
%ifarch ppc64
LDSO=/lib64/ld-lsb-ppc64.so.$LDSO_VERSION
%endif
%ifarch s390
LDSO=/lib/ld-lsb-s390.so.$LDSO_VERSION
%endif
%ifarch s390x
LDSO=/lib64/ld-lsb-s390x.so.$LDSO_VERSION
%endif
%ifarch ia64
LDSO=/lib/ld-lsb-ia64.so.$LDSO_VERSION
%endif
%ifarch x86_64
LDSO=/lib64/ld-lsb-x86-64.so.$LDSO_VERSION
%endif

# eventually change this to lsbcc
#CC="cc -Wl,--dynamic-linker=${LDSO}"
CC="lsbcc -DX11_t -DTRANS_CLIENT -DUNIXCONN"
CC=${CC} ./build.sh

# XXX - FIXME
# several tests (132) fail on fc8, opensuse10.3 with xcb
# rebuild without lsbcc for an alternate test binary we can use
for test in chngactvpn grbbttn grbpntr;do
  cd xts5/tset/Xlib13/$test
  cp Test Test.org
  grep lsbcc tet_captured | sed "s|^lsbcc|gcc -Wl,--dynamic-linker=${LDSO}|g;s|%{_builddir}/%{name}-%{version}/xts5/lib/libxtestlsbcc.a||g" > make.sh
  sh make.sh
  mv Test Test.xcb
  mv Test.org Test
  cd -
done

for test in chngwdwatt crtsmplwdw crtwdw dfncrsr undfncrsr;do
  cd xts5/tset/Xlib4/$test
  cp Test Test.org
  grep lsbcc tet_captured | sed "s|^lsbcc|gcc -Wl,--dynamic-linker=${LDSO}|g;s|%{_builddir}/%{name}-%{version}/xts5/lib/libxtestlsbcc.a||g" > make.sh
  sh make.sh
  mv Test Test.xcb
  mv Test.org Test
  cd -
done

# FIXME
# (sb) These 3 tests fail when built with lsbcc
# it seems to be keyed to using /opt/lsb/lib/libXt.so at the
# link stage, although I can't put my finger on why.
# Needed symbols are there, link goes fine, but the test
# fails: Xt3/tisvndrshl 1, Xt6/wdgttplvls 9, Xt6/wdgttrnsnt 9
#
# as a workaround, go back and re-link them using the system libXt
# we've disable Xt tests at the moment anyway, so we may be OK
LDFLAGS=`grep '^LDFLAGS\=' xts5/tetbuild.cfg | awk -F\= '{print $2}'`
CC="gcc -o Test Test.o $LDFLAGS /opt/lsb-tet3-lite/lib/tet3/tcm.o "
AR="../../../lib/libxtest.a ../../../lib/libxtestlsbcc.a ../../../lib/libXtTest.a /opt/lsb-tet3-lite/lib/tet3/libapi.a"
%ifarch x86_64 ppc64 s390x
LIB=lib64
%else
LIB=lib
%endif
XAWLIBS="/opt/lsb/$LIB/libXaw.a /opt/lsb/$LIB/libXmu.a /opt/lsb/$LIB/libXpm.a"
XLIBS="/usr/X11R6/$LIB/libXtst.a /opt/lsb/$LIB/libXext.so /opt/lsb/$LIB/libX11.so"
LINKER="-Wl,--dynamic-linker=${LDSO}"
LSBLIBS="/opt/lsb/$LIB/libc.so /opt/lsb/$LIB/libpthread.so /opt/lsb/$LIB/libm.so /opt/lsb/$LIB/libdl.so /opt/lsb/$LIB/libICE.so /opt/lsb/$LIB/libSM.so -lc_nonshared"
# hmm, we get glibc 2.4 symbol issues at link on ppc64 using the above
LSBLIBS="/opt/lsb/$LIB/libICE.so /opt/lsb/$LIB/libSM.so"

cd xts5/tset/Xt3/tisvndrshl
$CC $AR $XAWLIBS $XLIBS -lXt $LINKER $LSBLIBS
cd ../..
for DIR in Xt6/wdgttplvls Xt6/wdgttrnsnt;do
  cd $DIR
  $CC $AR $XLIBS -lXt $LINKER $LSBLIBS
  cd ../..
done
cd ../..

# patch tet_scen after we build, otherwise Xt tests don't build either
patch -p0 -b -z .drop-Xt-tests < %{PATCH5}

#==================================================
%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/fonts

# change the XT_FONTDIR and XT_FONTPATH preparing for install
TET_ROOT=`pwd`
cp -f configs/tetbuild.cfg.skel xts5/tetbuild.cfg
cp -f configs/tetexec.cfg.skel xts5/tetexec.cfg
cp -f xts5/tetexec.cfg xts5/tetexec.cfg.old
sed -e "s\\^XT_FONTDIR=\\XT_FONTDIR=/opt/lsb/test/lsb-xts5/xts5/fonts\\" \
    -e "s\\^XT_FONTPATH=\\XT_FONTPATH=/opt/lsb/test/lsb-xts5/xts5/fonts,\\" \
xts5/tetexec.cfg > xts5/tetexec.cfg.new
sed -i "s\\/usr/X11R6/lib/X11/fonts/misc\\/opt/lsb/share/fonts/misc\\" xts5/tetexec.cfg.new
sed -i "s\\/usr/lib/X11/fonts/100dpi/\\/opt/lsb/share/fonts/100dpi/\\" xts5/tetexec.cfg.new
sed -i "s\\/usr/lib/X11/fonts/75dpi/\\/opt/lsb/share/fonts/75dpi/\\" xts5/tetexec.cfg.new
mv -f xts5/tetexec.cfg.new xts5/tetexec.cfg

for testcase in mbdstr wcdstr wcdtext
do
    cp xts5/tset/Xlib14/$testcase/a1.C.dat xts5/tset/Xlib14/$testcase/a1.en_US.ISO8859-1.dat
done

# correct the BUILD_VERSION setting in run_xts5.sh
cat > change_version.sh << EOF
sed -e "s@BUILD_VERSION=@BUILD_VERSION=\"${RPM_PACKAGE_VERSION}-${RPM_PACKAGE_RELEASE} ($RPM_ARCH)\"@" run_xts5.sh \
       > ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/run_xts5.sh
EOF
chmod a+x change_version.sh && ./change_version.sh && rm -f change_version.sh
cp ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/run_xts5.sh run_xts5.sh

# install License, README and run_xts5.sh
cp -prf run_xts5.sh License README ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/run_xts5.sh

# install fonts
cp -prf xts5/fonts/xtfont*.pcf* ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/fonts
( cd ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/fonts && mkfontdir )

cd xts5
find bin configs lib scenarios tet_code tetexec.cfg tet_scen tet_tmp_dir man doc -print | cpio -pdv $RPM_BUILD_ROOT/opt/lsb/test/lsb-xts5/xts5

rsync -aH --exclude="*.[o|h|m|c]" --exclude="*.lsb*" --exclude="Makefile" --exclude="*asserts" --exclude="*.err" --exclude="tet*" tset ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5

# we need to define this at run time, not build time
rm -f ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/tset/Xlib17/gtdflt/.Xdefaults-`hostname`

# so any user can save results
install -d ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/results
chmod 0777 ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/results
# for .configured
install -d ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/lock
chmod 0777 ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/lock
# run_xts5.sh writes to this
chmod 0666 ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/fonts/fonts.dir
# so any user can setup the config from run_xts5.sh
chmod 0777 ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5
chmod 0666 ${RPM_BUILD_ROOT}/opt/lsb/test/lsb-xts5/xts5/tetexec.cfg

#==================================================
%clean
# uncomment later. leave in now for speed
if [ ! -z "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then 
    rm -rf ${RPM_BUILD_ROOT}
fi


#======================================================================
%post
rm -f /opt/lsb/test/lsb-xts5/lock/.configured > /dev/null 2>&1

echo
echo To run the tests, please execute the following command:
echo "    cd /opt/lsb/test/lsb-xts5; ./run_xts5.sh"
echo 

#==================================================
%files
%defattr(-,root,root)
%config(noreplace) /opt/lsb/test/lsb-xts5/xts5/tetexec.cfg

/opt/lsb/test/lsb-xts5/xts5
/opt/lsb/test/lsb-xts5/run_xts5.sh
/opt/lsb/test/lsb-xts5/License
/opt/lsb/test/lsb-xts5/README

%dir /opt/lsb/test/lsb-xts5
%dir /opt/lsb/test/lsb-xts5/lock

#==================================================
%changelog
* Tue Feb 12 2008 Stew Benedict <stewb@linux-foundation.org>
- fix UNREPORTED issues with Xlib4/stwdwbgpxm 7,8 
  on some platforms (bug 1937)

* Tue Jan 29 2008 Stew Benedict <stewb@linux-foundation.org>
- handle behavior change with XSizeHints structure 
  (flags needs to reflect the set of values to change, bug 1906, P8)

* Mon Jan 28 2008 Stew Benedict <stewb@linux-foundation.org>
- create tset/Xlib17/gtdflt/.Xdefaults-`hostname` at runtime,
  not build time (bug 1915)

* Thu Jan 24 2008 Stew Benedict <stewb@linux-foundation.org>
- Build/use alternate test binaries for some Xlib4, Xlib13
  tests that fail to run on xcb based systems (bug 1902, P7)

* Mon Jan 07 2008 Stew Benedict <stewb@linux-foundation.org>
- Modify kycdtkysym, lkpkysym tests to not use 'index'
  which is called out in updated strings.h (were not getting built)

* Tue Oct 30 2007 Stew Benedict <stewb@linux-foundation.org>
- add P6 to build with lsbcc (bug 1529) 
- use a workaround for the 3 remaining regressions
  (Xt tests, disabled in previous revision anyway)
- patch tet_scen (P5) after we build so Xt tests build

* Tue Oct 30 2007 Stew Benedict <stewb@linux-foundation.org>
- disable Xt tests in the "all" scenario (Bug 1371, P5)

* Fri Oct 19 2007 Stew Benedict <stewb@linux-foundation.org>
- change tests so any user can run them
  (copy directory structure to a tmp dir and symlink the tests)
- move the version/release stuff to the Makefile only

* Tue May 15 2007 Stew Benedict
- rediff P0
- split P0 into P0,P1,P2,P3 (generic, Xt, Xlib, XI)
- exclude the patch backup files
- add P4 for #1589 (BadMatch vs BadValue for crtclrmp)

* Thu Jun 23 2005 Rui Feng <fengrui@cn.ibm.com>
- And files into final package

* Mon Jun 20 2005 Rui Feng <fengrui@cn.ibm.com>
- Initial checkin 
